@@ -1,14 +1,21 @@
 /*
- * ExampleToolbar.java
+ * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright (c) 2007 Operational Dynamics Consulting Pty Ltd
- * Copyright (c) 2007 Vreixo Formoso
+ * Copyright © 2007-2010 Operational Dynamics Consulting, Pty Ltd
+ * Copyright © 2007      Vreixo Formoso
  *
- * The code in this file, and the library it is a part of, are made available
- * to you by the authors under the terms of the "GNU General Public Licence,
- * version 2" plus the "Classpath Exception" (you may link to this code as a
- * library into other programs provided you don't make a derivation of it).
- * See the LICENCE file for the terms governing usage and redistribution.
+ * The code in this file, and the program it is a part of, is made available
+ * to you by its authors as open source software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License version
+ * 2 ("GPL") as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.
+ *
+ * You should have received a copy of the GPL along with this program. If not,
+ * see http://www.gnu.org/licenses/. The authors of this program may be
+ * contacted through http://java-gnome.sourceforge.net/.
  */
 package menu;
 
@@ -27,9 +34,6 @@ import org.gnome.gtk.Toolbar;
 import org.gnome.gtk.VBox;
 import org.gnome.gtk.Widget;
 import org.gnome.gtk.Window;
-import org.gnome.gtk.ToggleToolButton.TOGGLED;
-import org.gnome.gtk.ToolButton.CLICKED;
-import org.gnome.gtk.Window.DELETE_EVENT;
 
 /**
  * How to use {@link Toolbar} and related Widgets.
@@ -75,11 +79,11 @@ public class ExampleToolbar
 
         /*
          * You can respond to user clicks in the ToolButton connecting to the
-         * CLICKED signal.
+         * ToolButton.Clicked signal.
          */
-        buttonNew.connect(new CLICKED() {
-            public void onClicked(ToolButton sourceObject) {
-                l.setLabel("You have click NEW ToolButton");
+        buttonNew.connect(new ToolButton.Clicked() {
+            public void onClicked(ToolButton source) {
+                l.setLabel("You have clicked NEW ToolButton");
             }
         });
 
@@ -95,14 +99,14 @@ public class ExampleToolbar
          * You can add your Menu to this kind of ToolButtons
          */
         openMenu = new Menu();
-        openMenu.append(new MenuItem("File _A", new MenuItem.ACTIVATE() {
-            public void onActivate(MenuItem sourceObject) {
-                l.setLabel("You have select File A in the Menu");
+        openMenu.append(new MenuItem("File _A", new MenuItem.Activate() {
+            public void onActivate(MenuItem source) {
+                l.setLabel("You have selected File A in the Menu");
             }
         }));
-        openMenu.append(new MenuItem("File _B", new MenuItem.ACTIVATE() {
-            public void onActivate(MenuItem sourceObject) {
-                l.setLabel("You have select File B in the Menu");
+        openMenu.append(new MenuItem("File _B", new MenuItem.Activate() {
+            public void onActivate(MenuItem source) {
+                l.setLabel("You have selected File B in the Menu");
             }
         }));
         openMenu.showAll();
@@ -111,9 +115,9 @@ public class ExampleToolbar
         /*
          * You also can respond to user clicks in the MenuToolButton itself
          */
-        mtb.connect(new CLICKED() {
-            public void onClicked(ToolButton sourceObject) {
-                l.setLabel("You have click the Open MenuToolButton");
+        mtb.connect(new ToolButton.Clicked() {
+            public void onClicked(ToolButton source) {
+                l.setLabel("You have clicked the Open MenuToolButton");
             }
         });
 
@@ -138,9 +142,9 @@ public class ExampleToolbar
 
         /*
          * the changes in the active state can be tracked by connecting to the
-         * TOGGLED signal.
+         * ToggleToolButton.Toggled signal.
          */
-        boldButton.connect(new TOGGLED() {
+        boldButton.connect(new ToggleToolButton.Toggled() {
             public void onToggled(ToggleToolButton source) {
                 /* You can get the state with the getActive() method */
                 if (source.getActive()) {
@@ -163,7 +167,7 @@ public class ExampleToolbar
         item.add(new Label("This is a label"));
         toolbar.add(item);
 
-        w.connect(new DELETE_EVENT() {
+        w.connect(new Window.DeleteEvent() {
             public boolean onDeleteEvent(Widget source, Event event) {
                 Gtk.mainQuit();
                 return false;
