@@ -1,22 +1,44 @@
 /*
- * Object.java
+ * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright (c) 2006-2008 Operational Dynamics Consulting Pty Ltd
- * 
- * The code in this file, and the library it is a part of, are made available
- * to you by the authors under the terms of the "GNU General Public Licence,
- * version 2" plus the "Classpath Exception" (you may link to this code as a
- * library into other programs provided you don't make a derivation of it).
- * See the LICENCE file for the terms governing usage and redistribution.
+ * Copyright © 2006-2010 Operational Dynamics Consulting, Pty Ltd
+ *
+ * The code in this file, and the program it is a part of, is made available
+ * to you by its authors as open source software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License version
+ * 2 ("GPL") as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.
+ *
+ * You should have received a copy of the GPL along with this program. If not,
+ * see http://www.gnu.org/licenses/. The authors of this program may be
+ * contacted through http://java-gnome.sourceforge.net/.
+ *
+ * Linking this library statically or dynamically with other modules is making
+ * a combined work based on this library. Thus, the terms and conditions of
+ * the GPL cover the whole combination. As a special exception (the
+ * "Claspath Exception"), the copyright holders of this library give you
+ * permission to link this library with independent modules to produce an
+ * executable, regardless of the license terms of these independent modules,
+ * and to copy and distribute the resulting executable under terms of your
+ * choice, provided that you also meet, for each linked independent module,
+ * the terms and conditions of the license of that module. An independent
+ * module is a module which is not derived from or based on this library. If
+ * you modify this library, you may extend the Classpath Exception to your
+ * version of the library, but you are not obligated to do so. If you do not
+ * wish to do so, delete this exception statement from your version.
  */
 package org.gnome.glib;
 
-import java.util.HashSet;
+import java.util.ArrayList;
 
 import org.freedesktop.bindings.Constant;
 import org.freedesktop.bindings.Debug;
 import org.freedesktop.bindings.Flag;
 import org.freedesktop.bindings.Proxy;
+import org.gnome.pango.FontDescription;
 
 /**
  * Base class of the object system used by GLib and libraries based on it,
@@ -27,13 +49,13 @@ import org.freedesktop.bindings.Proxy;
  * 
  * <p>
  * <i>Methods here provide the mechanism to get and set "properties" on the
- * underlying <code>GObject</code>s. As a deliberate design decision to
- * ensure type safety, however, these are not exposed for public use. To offer
- * a getter or setter for a property, a java-gnome subclass must expose an
- * explicitly named method. For example, to set the</i> "<code>righteous</code>"
- * <i>property, (assuming that the <code>GObject</code> in question has such
- * a property, that it is writable, and that it takes a string), create a
- * method like this:</i>
+ * underlying <code>GObject</code>s. As a deliberate design decision to ensure
+ * type safety, however, these are not exposed for public use. To offer a
+ * getter or setter for a property, a java-gnome subclass must expose an
+ * explicitly named method. For example, to set the</i> <var>righteous</var>
+ * <i>property, (assuming that the <code>GObject</code> in question has such a
+ * property, that it is writable, and that it takes a string), create a method
+ * like this:</i>
  * 
  * <pre>
  * public void setRighteous(String value) {
@@ -67,7 +89,7 @@ public abstract class Object extends Proxy
      * a weak Java reference from the BindingsJavaClosure on the JNI side. See
      * bindings_java_signal.c in src/jni.
      */
-    private HashSet<Signal> handlers;
+    private ArrayList<Signal> handlers;
 
     protected Object(long pointer) {
         super(pointer);
@@ -78,20 +100,6 @@ public abstract class Object extends Proxy
         GObject.addToggleRef(this);
     }
 
-    /**
-     * Take the actions necessary to release our reference to the underlying
-     * GObject, then carry on to
-     * {@link org.freedesktop.bindings.Proxy#finalize() Proxy's finalize()}.
-     */
-    /*
-     * This is a placeholder to remind us of the cleanup actions that will be
-     * necessary, irrespective of the finalizer technique used.
-     */
-    protected void finalize() {
-        release();
-        super.finalize();
-    }
-
     /**
      * Drop our reference count to the underlying GObject.
      * 
@@ -136,6 +144,13 @@ public abstract class Object extends Proxy
         GObject.setProperty(this, name, new Value(value));
     }
 
+    protected int getPropertyInteger(String name) {
+        final Value value;
+
+        value = GObject.getProperty(this, name);
+        return GValue.getInteger(value);
+    }
+
     /**
      * Set a property that takes a <code>boolean</code> for its value.
      * 
@@ -150,7 +165,9 @@ public abstract class Object extends Proxy
     }
 
     protected boolean getPropertyBoolean(String name) {
-        Value value = GObject.getProperty(this, name);
+        final Value value;
+
+        value = GObject.getProperty(this, name);
         return GValue.getBoolean(value);
     }
 
@@ -164,10 +181,23 @@ public abstract class Object extends Proxy
     }
 
     protected float getPropertyFloat(String name) {
-        Value value = GObject.getProperty(this, name);
+        final Value value;
+
+        value = GObject.getProperty(this, name);
         return GValue.getFloat(value);
     }
 
+    protected void setPropertyDouble(String name, double value) {
+        GObject.setProperty(this, name, new Value(value));
+    }
+
+    protected double getPropertyDouble(String name) {
+        final Value value;
+
+        value = GObject.getProperty(this, name);
+        return GValue.getDouble(value);
+    }
+
     /**
      * Set a property that takes an Object subclass for its value.
      * 
@@ -178,17 +208,27 @@ public abstract class Object extends Proxy
     }
 
     protected String getPropertyString(String name) {
-        Value value = GObject.getProperty(this, name);
+        final Value value;
+
+        value = GObject.getProperty(this, name);
         return GValue.getString(value);
     }
 
+    protected void setPropertyEnum(String name, Constant value) {
+        GObject.setProperty(this, name, new Value(value));
+    }
+
     protected Constant getPropertyEnum(String name) {
-        Value value = GObject.getProperty(this, name);
+        final Value value;
+
+        value = GObject.getProperty(this, name);
         return GValue.getEnum(value);
     }
 
     protected Flag getPropertyFlags(String name) {
-        Value value = GObject.getProperty(this, name);
+        final Value value;
+
+        value = GObject.getProperty(this, name);
         return GValue.getFlags(value);
     }
 
@@ -204,19 +244,27 @@ public abstract class Object extends Proxy
      * @since 4.0.1
      */
     protected Object getPropertyObject(String name) {
-        Value value = GObject.getProperty(this, name);
+        final Value value;
+
+        value = GObject.getProperty(this, name);
         return GValue.getObject(value);
     }
 
+    protected void setPropertyBoxed(String name, FontDescription desc) {
+        GObject.setProperty(this, name, new Value(desc));
+    }
+
     /**
      * When a Signal handler is connected, we maintain a strong reference from
      * here. We don't use it for anything, just memory management. Only called
-     * from {@link Plumbing#connectSignal(Object, Signal, Class, String)}.
+     * from Plumbing.connectSignal().
      */
     void addHandler(Signal handler) {
-        if (handlers == null) {
-            handlers = new HashSet<Signal>();
+        synchronized (this) {
+            if (handlers == null) {
+                handlers = new ArrayList<Signal>(1);
+            }
+            handlers.add(handler);
         }
-        handlers.add(handler);
     }
 }
